.. _community-guide:

=========
Community
=========


Welcome to the Community Guides for Jupyter. These guides are intended to
provide information about the Jupyter community such as background, events,
and communication channels. As our community is highly dynamic, information
may change, and we will do our best to keep it up to date.

.. TODO: remove this hidden toctree when left sidebar TOCs work in pydata sphinx theme

.. toctree::
   :hidden:

   community-call-notes/index

Jupyter Community Meetings
==========================

The Jupyter community often meets (usually on-line) in order to discuss matters in
the Jupyter community, share new ideas and discussions, and connect with one another.
This often happens within specific sub-project (more information below), though
there are also occasional community-wide meetings.

Some of these meetings are recorded and uploaded to our `YouTube channel <https://www.youtube.com/@projectjupyter>`_.
**Please do not record meetings on your own.** Some of our meetings include both
on-the-record and off-the-record segments; off-record segments are not recorded or
published.

This following calendar shows the various meetings and events from Jupyter sub-projects:

.. raw:: html

    <iframe src="https://calendar.google.com/calendar/embed?height=600&amp;wkst=1&amp;bgcolor=%23ffffff&amp;ctz=America%2FLos_Angeles&amp;src=ZGdwZDM2ZjQzZXQ5Z3JhYm42dGRpbjZwbWNAZ3JvdXAuY2FsZW5kYXIuZ29vZ2xlLmNvbQ&amp;src=bTNoZWs2OWRhZzczODF1bXQ4a2NqZDc1dTRAZ3JvdXAuY2FsZW5kYXIuZ29vZ2xlLmNvbQ&amp;src=YXFwa3VpNXE3b2kzMnBrOXRjcDUzaG5zc2NAZ3JvdXAuY2FsZW5kYXIuZ29vZ2xlLmNvbQ&amp;src=ZDE4NzR1cjZmZGh1ajBzbmpuaWxhYzJubGNAZ3JvdXAuY2FsZW5kYXIuZ29vZ2xlLmNvbQ&amp;src=cGlhaGluZWpqcjZzc3ZpOGlrbWpqb3A2cm9AZ3JvdXAuY2FsZW5kYXIuZ29vZ2xlLmNvbQ&amp;color=%23AD1457&amp;color=%23EF6C00&amp;color=%23616161&amp;color=%23F6BF26&amp;color=%239E69AF" style="border:solid 1px #777" width="800" height="600" frameborder="0" scrolling="no"></iframe>


Jupyter-wide meetings
---------------------

**All-Jupyter Community Calls** generally happen on the last Tuesday of the month,
and are focused around demonstrations and sharing information across all of the Jupyter projects.

- Find information on `this Discourse thread <https://discourse.jupyter.org/t/all-jupyter-community-calls/668>`_.
- Watch previous calls on `our YouTube channel <https://www.youtube.com/playlist?list=PLUrHeD2K9Cmkoamm4NjLmvXC4Y6E1o8SP>`_.
- Read the `notes from previous calls <community-call-notes/index.html>`_.

In addition, you can find the notes from previous community meetings below.

.. toctree::

   community-call-notes/index

Jupyter Project meetings
------------------------

The core developers of various Jupyter sub-projects have regular meetings to
discuss and demo what they have been working on, discuss future plans,
and bootstrap conversation. These meetings are public and you are welcome to join remotely.

Each team has their own processes around logistics and planning for the team meetings. The
following pages should help you find the information for each.


**JupyterHub meetings** happen monthly. For a calendar of future team meetings, see
`the JupyterHub team compass repository <https://jupyterhub-team-compass.readthedocs.io/en/latest/meetings/index.html>`_.

**JupyterLab meetings** happen weekly. For more information about when these meetings happen,
as well as notes from each meeting, see `the JupyterLab README <https://github.com/jupyterlab/jupyterlab#weekly-dev-meeting>`_.

**General meeting conversation and planning** often happens in the
`dev-meeting-attendance Gitter channel <https://gitter.im/jupyter/dev-meeting-attendance>`_.
We recommend checking it periodically for new information about when meetings are happening.

.. contents:: Contents
   :local:


Jupyter communications
======================

As a general rule, most project-wide conversation happens in the
`Jupyter community forum <https://discourse.jupyter.org>`_. There are also many other
kinds of communication that happens within the community. See below for links and other
relevant information.

- Community forum `<https://discourse.jupyter.org/>`_
- Blog `<https://blog.jupyter.org/>`_
- Newsletter `<https://newsletter.jupyter.org/>`_
- Website `<https://jupyter.org>`_
- Twitter `<https://twitter.com/ProjectJupyter>`_
- Gitter `<https://gitter.im/jupyter/jupyter>`_
- Mailing lists (Jupyter, Jupyter in Education) `<https://jupyter.org/community.html>`_


Governance
==========

- Steering council: Information about the steering council and its members
  can be found on the `Jupyter website <https://jupyter.org/about>`_.
- Information about Jupyter's governance process can be found on
  `the Jupyter governance website <https://jupyter.org/governance>`_.
- Jupyter Enhancement Proposal (JEP) process: Details about the process can
  be found in the `enhancement proposals website <https://jupyter.org/enhancement-proposals>`_.


Code of conduct
===============

Information can be found in the
`Jupyter Code of Conduct page <https://jupyter.org/governance/conduct/code_of_conduct.html>`_.


Running Jupyter Events
======================

Members of the Jupyter community often get together to share what they're
working on, to work together, and to teach and learn from one another.

If you're organizing an event with the Jupyter community (whether it's as
small as a JupyterDays meetup, or as large as JupyterCon) you should ensure
that the event follows the values and goals of the Jupyter project - to be a
place where *everyone* feels welcome and supported and that reflects the
diversity of developers and users in the Jupyter community.

Shoot for having **25% of your participants come from under-represented
groups**. If you're organizing a Jupyter event,
here are some resources to help out.

* **Mozilla** has a number of excellent resources on hosting open events.
  The `Mozilla Open Events guide <https://foundation.mozilla.org/en/opportunity/open-events-guide/>`_.
  This is an excellent resource for planning and running an open, inclusive
  event. In particular, `this section on making events more inviting <https://foundation.mozilla.org/en/opportunity/open-events-guide/make-it-more-inviting/>`_
  is a good way to make your event more welcoming, interesting, and accessible
  to the Jupyter community. Finally, the `Diversity and Inclusion wiki includes
  conference calls related to this topic <https://wiki.mozilla.org/Diversity_and_Inclusion_for_Communities_and_Contributors>`_.
* The `NumFocus DISCOVER cookbook <https://discover-cookbook.numfocus.org/>`_
  is another collection of resources for making your event more productive,
  diverse, and inclusive.
* The `National Center for Women & Information Technology <https://www.ncwit.org/>`_ has an excellent
  collection of resources for creating a diverse and inclusive environment. In
  particular, we recommend their `Inclusive Environment Assessment Guide <https://www.ncwit.org/sites/default/files/file_type/ncwit_inclusiveenvironmentalassessment_guide.pdf>`_
  and `10 actionable ways to actually increase diversity <https://www.ncwit.org/resources/10-actionable-ways-actually-increase-diversity-tech>`_.
* The `PyCascades <https://pycascades.com>`_ community has `several efforts in improving diversity and inclusion <https://2019.pycascades.com/diversity-and-inclusion/>`_.
* `Write the Docs <http://www.writethedocs.org/>`_ has a `Welcome Wagon Guide <https://www.writethedocs.org/organizer-guide/confs/welcome-wagon/>`_
  to help first-time attendees feel welcome and included.

Ultimately, making events more inclusive is not rocket science and there is
no magic bullet. It requires clear, focused dedication, planning ahead,
and sustained resources and effort over time. However, we believe this effort
is worth it!


What is a Jovyan?
=================

You may see the word **Jovyan** used in Jupyter tools (such as the user ID in the
`Jupyter Docker stacks <https://github.com/jupyter/docker-stacks?>`_ or referenced in
conversations. But what is a Jovyan?

In astronomical terms, the word "Jovian" means "like Jupiter". It describes
`several planets that share Jupiter-like properties <https://www.universetoday.com/33061/what-are-the-jovian-planets/>`_.

Much like the planet Jupiter and our solar system, the Jupyter community
is large, distributed, and nebulous. We like to use the word **Jovyan** to
describe members of this community. Jovyans are fellow open enthusiasts that use, develop,
promote, teach, learn, and otherwise enjoy tools in Jupyter's orbit. They make up the
Jupyter community. If you're not sure whether you're a Jovyan, you probably are :-)
